@@ -7,7 +7,7 @@ use Mite::Miteception;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002000';
+our $VERSION   = '0.002001';
 
 use Path::Tiny;
 use mro;
@@ -141,7 +141,7 @@ sub _get_parent {
     return $parent if $parent;
 
     # If not, try to load it
-    require $parent;
+    eval "require $parent;";
     $parent = $project->class($parent_name);
     return $parent if $parent;
 
